@@ -6,10 +6,7 @@ from .kradle import Kradle
 from .models import InitParticipantResponse, MinecraftEvent, Observation, OnEventResponse
 from .mc import MC
 from .agent_manager import AgentManager
-from kradle.memory.standard_memory import StandardMemory
 
-# from kradle.memory.firestore_memory import FirestoreMemory
-from kradle.memory.redis_memory import RedisMemory
 from kradle.api.client import KradleAPI
 from kradle.api.http import KradleAPIError
 from kradle.api.resources import ChallengeParticipant
@@ -28,10 +25,7 @@ __all__ = [
     "Observation",
     "MinecraftEvent",
     "MC",
-    "StandardMemory",
     "ChallengeParticipant",
-    ##"FirestoreMemory",
-    "RedisMemory",
     "InitParticipantResponse",
     "OnEventResponse",
     "JSON_RESPONSE_FORMAT",
