@@ -78,6 +78,11 @@ class GameMode(str, Enum):
     SPECTATOR = "spectator"
 
 
+class RunStatus(str, Enum):
+    STARTED = "started"
+    GAME_OVER = "game_over"
+
+
 @dataclass
 class ChatMessage:
     sender: str
@@ -113,6 +118,13 @@ class Observation:
         past_observation_id (Optional[str]): Reference to previous observation
             Example: "obs-1234-5677"
 
+    Challenge State Information:
+        run_status (RunStatus): Current challenge state
+            Example: RunStatus.STARTED
+        winner (bool): Is the current objective reached
+            Example: False
+        score (float): Current score
+
     Event Information:
         event (str): Current event type from EventType enum
             Example: "chat", "death", "idle"
@@ -152,16 +164,6 @@ class Observation:
             Example: 13000
         time_of_day (TimeOfDay): Time category enum
             Example: TimeOfDay.MORNING
-        day_count (int): Number of in-game days passed
-            Example: 42
-        rain_state (float): Rain intensity from 0-1
-            Example: 0.7
-        thunder_state (float): Thunder intensity from 0-1
-            Example: 0.0
-        light_level (int): Block light level (0-15)
-            Example: 14
-        dimension (str): Current dimension name
-            Example: "overworld", "nether", "end"
 
     World State:
         players (List[str]): Names of nearby players
@@ -205,11 +207,17 @@ class Observation:
     observation_id: str = ""
     past_observation_id: Optional[str] = None
 
+    # Challenge state
+    run_status: RunStatus = RunStatus.STARTED
+    winner: bool = False
+    score: float = 0.0
+
     # Event info
     event: str = "idle"
     idle: bool = True
     executing: Optional[str] = None
     output: Optional[str] = None
+    interrupted: "list[InterruptedAction]" = field(default_factory=list)
 
     # Location
     position: dict[str, float] = field(default_factory=dict)
@@ -218,6 +226,7 @@ class Observation:
     health: float = 1.0  # Normalized to 0-1 range
     hunger: float = 1.0  # Normalized to 0-1 range
     xp: float = 0.0
+    lives: int = -1
     gamemode: GameMode = GameMode.SURVIVAL
     is_alive: bool = True
     on_ground: bool = True
@@ -228,11 +237,7 @@ class Observation:
     weather: Weather = Weather.CLEAR
     time: int = 0  # 0-24000
     time_of_day: TimeOfDay = TimeOfDay.MORNING
-    day_count: int = 0
-    rain_state: float = 0.0
-    thunder_state: float = 0.0
-    light_level: int = 15
-    dimension: str = "overworld"
+    screenshot: Optional[str] = None
 
     # World state
     players: list[str] = field(default_factory=list)
@@ -263,18 +268,24 @@ class Observation:
                 participant_id=str(data.get("participantId", "")),
                 run_id=str(data.get("runId", "")),
                 observation_id=str(data.get("observationId", "")),
-                past_observation_id=data.get("past_observationid"),
+                past_observation_id=data.get("pastObservationId"),
+                # Challenge state
+                run_status=RunStatus(str(data.get("runStatus", "started"))),
+                winner=bool(data.get("winner", False)),
+                score=float(data.get("score", 0.0)),
                 # Event
                 event=str(data.get("event", "idle")),
                 idle=bool(data.get("idle", True)),
                 executing=data.get("executing"),
                 output=data.get("output"),
+                interrupted=InterruptedAction.from_event_list(data.get("interrupted", [])),
                 # Location
                 position=data.get("position", {}),
                 # Player State
                 health=health,
                 hunger=hunger,
                 xp=float(data.get("xp", 0)),
+                lives=int(data.get("lives", -1)),
                 gamemode=GameMode(str(data.get("gamemode", "survival"))),
                 is_alive=bool(data.get("is_alive", True)),
                 on_ground=bool(data.get("on_ground", True)),
@@ -284,11 +295,7 @@ class Observation:
                 weather=Weather(str(data.get("weather", "clear"))),
                 time=time,
                 time_of_day=TimeOfDay(str(data.get("timeOfDay", "morning"))),
-                day_count=int(data.get("day_count", 0)),
-                rain_state=float(data.get("rain_state", 0)),
-                thunder_state=float(data.get("thunder_state", 0)),
-                light_level=int(data.get("light_level", 15)),
-                dimension=str(data.get("dimension", "overworld")),
+                screenshot=data.get("screenshot", None),
                 # World State
                 players=list(data.get("players", [])),
                 blocks=list(data.get("blocks", [])),
@@ -301,7 +308,7 @@ class Observation:
                         chat_msg=("to me: " if msg.get("dm", False) else " to general chat: ")
                         + str(msg.get("message", "")),
                     )
-                    for msg in data.get("chat_messages", [])
+                    for msg in data.get("chatMessages", [])
                 ],
             )
         except Exception as e:
@@ -329,11 +336,9 @@ class Observation:
 
             Location & Environment:
             - Position: x={x}, y={y}, z={z}
-            - Dimension: {self.dimension}
             - Biome: {self.biome}
             - Time: {self.time_of_day}
             - Weather: {self.weather}
-            - Light Level: {self.light_level}
 
             World State:
             - Nearby Blocks: {", ".join(self.blocks) if self.blocks else "None"}
@@ -354,6 +359,20 @@ class Observation:
         return json.dumps(asdict(self), indent=4, default=str)
 
 
+@dataclass
+class InterruptedAction:
+    output: str
+    past_observation_id: str
+
+    @classmethod
+    def from_event(cls, item: dict[str, Any]) -> "InterruptedAction":
+        return cls(output=item.get("output", ""), past_observation_id=item.get("pastObservationId", ""))
+
+    @classmethod
+    def from_event_list(cls, data: list[dict[str, Any]]) -> "list[InterruptedAction]":
+        return [InterruptedAction.from_event(item) for item in data]
+
+
 class InitParticipantResponse(TypedDict):
     """The response from the server when an agent is initialized."""
 
@@ -368,6 +387,7 @@ class OnEventResponse(TypedDict):
     message: str
     thoughts: NotRequired[str]
     delay: NotRequired[float]
+    cost: NotRequired[float]
     # we may add more fields in the future
 
 
